==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.yu = new ScatterFrame();
        _this.yw = new ScatterFrame();
        _this.ys = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.dl.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.dl.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.yu.o = a;
        _this.yw.o = a;
        _this.ys.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.bi = function () {
        return new ScatterLineSeries();
    };
    ScatterLineSeries.prototype.get_fi = function () {
        return true;
    };
    ScatterLineSeries.prototype.cq = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.zo = function () {
        return true;
    };
    ScatterLineSeries.prototype.ji = function () {
        if (!isNaN_(this.jh)) {
            return _super.prototype.ji.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.gu = function (a, b) {
        if (this.w9(a, b)) {
            return true;
        }
        if (this.acf(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.acf = function (a, b) {
        var c = this.ct;
        var d = c.dl;
        return this.gv(a, b, d.an);
    };
    ScatterLineSeries.prototype.aa6 = function (a, b) {
        var _this = this;
        _super.prototype.aa6.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.ib * this.ib;
        var g = 0;
        if (this.y9 != null) {
            g = this.y9.count;
        }
        if (this.za != null) {
            g = Math.min(this.za.count, g);
        }
        var h = new ScalerParams(0, c, d, this.yo.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.yo.e, e);
            $ret.b = _this.iw();
            return $ret;
        })());
        var j = arrayShallowClone(this.y9.asArray());
        var k = arrayShallowClone(this.za.asArray());
        this.xAxis.ho(boxArray$1(j), 0, j.length, h);
        this.yAxis.ho(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.z1) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (isNaN_(u) || u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.acm(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.dl.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.z1) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.acm = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_zi = function () {
        return true;
    };
    ScatterLineSeries.prototype.abh = function (a, b) {
        b.c9(false);
        _super.prototype.abh.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bx.left, b.bx.top, b.bx.width, b.bx.height);
        d = RectUtil.t(d, this.ic, this.ic);
        this.aba(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.y1.az(this, this.zn(), runOn(this, this.yh));
        var f = false;
        var g = this.y1.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.aa2(-1, this.y9.count, b.q);
        }
        this.y1.ad(e.dl, true, false, true, false);
        this.ack(e.dl, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.ace, this.ib);
    };
    ScatterLineSeries.prototype.ack = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.acj(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.acj(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.acg = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.acj = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.jh) ? f : 1;
            var h = this.acg(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.q5 = function (a, b, c, d) {
        _super.prototype.q5.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.rn(false);
                this.qh();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:ace:acl', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };

==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.y7 = new ScatterFrame();
        _this.y9 = new ScatterFrame();
        _this.y5 = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.dp.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.dp.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.y7.p = a;
        _this.y9.p = a;
        _this.y5.p = a;
        return _this;
    }
    ScatterLineSeries.prototype.bk = function () {
        return new ScatterLineSeries();
    };
    ScatterLineSeries.prototype.get_fl = function () {
        return true;
    };
    ScatterLineSeries.prototype.ct = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.z1 = function () {
        return true;
    };
    ScatterLineSeries.prototype.jl = function () {
        if (!isNaN_(this.jk)) {
            return _super.prototype.jl.call(this);
        }
        return Defaults.ak;
    };
    ScatterLineSeries.prototype.gx = function (a, b) {
        if (this.xm(a, b)) {
            return true;
        }
        if (this.act(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.act = function (a, b) {
        var c = this.cw;
        var d = c.dz;
        return this.gy(a, b, d.an);
    };
    ScatterLineSeries.prototype.abk = function (a, b) {
        var _this = this;
        _super.prototype.abk.call(this, a, b);
        a.n.clear();
        a.v.clear();
        var c = b.ca;
        var d = b.b9;
        var e = this.getEffectiveViewport1(b);
        var f = this.ie * this.ie;
        var g = 0;
        if (this.zm != null) {
            g = this.zm.count;
        }
        if (this.zn != null) {
            g = Math.min(this.zn.count, g);
        }
        var h = new ScalerParams(0, c, d, this.y1.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.y1.e, e);
            $ret.b = _this.iz();
            return $ret;
        })());
        var j = arrayShallowClone(this.zm.asArray());
        var k = arrayShallowClone(this.zn.asArray());
        this.xAxis.hq(boxArray$1(j), 0, j.length, h);
        this.yAxis.hq(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.n;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.aae) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (isNaN_(u) || u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.ac0(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.dp.item(r);
                if (!a.v.containsKey(v.a)) {
                    a.v.addItem(v.a, v);
                }
            }
        }
        if (g > this.aae) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.ac0 = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_zv = function () {
        return true;
    };
    ScatterLineSeries.prototype.abv = function (a, b) {
        b.dm(false);
        _super.prototype.abv.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.b9.left, b.b9.top, b.b9.width, b.b9.height);
        d = RectUtil.t(d, this.ig, this.ig);
        this.abo(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.ze.az(this, this.z0(), runOn(this, this.yu));
        var f = false;
        var g = this.ze.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.abg(-1, this.zm.count, b.t);
        }
        this.ze.ad(e.dz, true, false, true, false);
        this.acy(e.dz, a.n.count, function (h) { return a.n._inner[h].x; }, function (h) { return a.n._inner[h].y; }, this.acs, this.ie);
    };
    ScatterLineSeries.prototype.acy = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.acx(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.acx(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.acu = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.acx = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.jk) ? f : 1;
            var h = this.acu(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.rc = function (a, b, c, d) {
        _super.prototype.rc.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.ru(false);
                this.qn();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acs:acz', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };
